pub fn aerosol_type_code(header: &Grib2MessageHeader) -> Option<u16>Expand description
Return the aerosol type code from the common aerosol product-template prefix. The Section 4 payload starts with the coordinate count and template number, followed by category/parameter; aerosol type is the next two octets for the aerosol templates.