pub fn normalize_longitude(value: f64) -> f64Expand description
Normalize geographic longitudes to the convention used in the viewer. Non-finite values are preserved so missing coordinate diagnostics are not turned into arbitrary geographic positions.